@@ -25,12 +25,12 @@ class Model:
 
             self.state = self.car.get_state(self.vue)
 
-            progress = self.vue.get_progress(self.car.position)
-            self.reward = progress - self.progress
-            if self.reward > 1000 :
-                self.reward = -self.reward  # avoid going directly back during after start. 
-                self.done = True
+            progress, circuit_lenght = self.vue.get_progress(self.car.position)
+            
+            if progress - self.progress > 1000 : # detect if the car went back after departure
+                progress = progress - circuit_lenght
 
+            self.reward = progress - self.progress
             self.progress = progress
 
             if not self.vue.is_road(self.car.position):
