@@ -22,5 +22,5 @@ class Camera:
                     value = 240
                 except :
                     raise
-                valurs.append(value)
+                values.append(value)
             return values
\ No newline at end of file
