@@ -12,7 +12,7 @@ class MapRegistery:
 				'position' : (490, 520),
 				'orientation' : 17
 				},
-			'schema' : [(490, 530), (480, 490), (470, 465), (460, 440), (460, 325), (470, 300), (500, 270), (530, 260), (570, 207), (623, 130), (600, 85), (540, 80), (486, 155), (450, 180), (414, 140), (390, 80), (125, 80), (85, 108), (78, 156), (100, 200), (130, 210), (355, 230), (378, 255), (362, 290), (215, 344), (190, 375), (212, 423), (303, 535), (392, 617), (470, 630), (499, 594), (490, 540)]
+			'schema' : [(490, 520), (480, 490), (470, 465), (460, 440), (460, 325), (470, 300), (500, 270), (530, 260), (570, 207), (623, 130), (600, 85), (540, 80), (486, 155), (450, 180), (414, 140), (390, 80), (125, 80), (85, 108), (78, 156), (100, 200), (130, 210), (355, 230), (378, 255), (362, 290), (215, 344), (190, 375), (212, 423), (303, 535), (392, 617), (470, 630), (499, 594), (490, 540), (490, 520)]
 		},
 
 		'map_2' : {
